@@ -867,7 +867,7 @@ class t3lib_DB {
 	 * @see exec_SELECTquery(), stripGroupBy()
 	 */
 	function stripOrderBy($str) {
-		return preg_replace('/^ORDER[[:space:]]+BY[[:space:]]+/i', '', trim($str));
+		return preg_replace('/^(?:ORDER[[:space:]]*BY[[:space:]]*)+/i', '', trim($str));
 	}
 
 	/**
@@ -881,7 +881,7 @@ class t3lib_DB {
 	 * @see exec_SELECTquery(), stripOrderBy()
 	 */
 	function stripGroupBy($str) {
-		return preg_replace('/^GROUP[[:space:]]+BY[[:space:]]+/i', '', trim($str));
+		return preg_replace('/^(?:GROUP[[:space:]]*BY[[:space:]]*)+/i', '', trim($str));
 	}
 
 	/**
