@@ -703,7 +703,7 @@ class t3lib_pageSelect {
 					// Add row to rootline with language overlaid:
 				$theRowArray[] = $this->getPageOverlay($row);
 			} else {
-				$this->error_getRootLine = 'Broken rootline';
+				$this->error_getRootLine = 'Broken rootline (failed on page with uid ' . $uid . ')';
 				$this->error_getRootLine_failPid = $uid;
 				return array(); // broken rootline.
 			}
@@ -1089,9 +1089,26 @@ class t3lib_pageSelect {
 				$query .= ' AND ' . $table . '.' . $ctrl['delete'] . '=0';
 			}
 
-				// Filter out new place-holder records in case we are NOT in a versioning preview (that means we are online!)
-			if ($ctrl['versioningWS'] && !$this->versioningPreview) {
-				$query .= ' AND ' . $table . '.t3ver_state<=0 AND ' . $table . '.pid<>-1'; // Shadow state for new items MUST be ignored!
+			if ($ctrl['versioningWS']) {
+				if (!$this->versioningPreview) {
+					// Filter out placeholder records (new/moved/deleted items)
+					// in case we are NOT in a versioning preview (that means we are online!)
+					$query .= ' AND ' . $table . '.t3ver_state<=0';
+				} else {
+					if ($table !== 'pages') {
+						// show only records of live and of the current workspace
+						// in case we are in a versioning preview
+						$query .= ' AND ('
+							. $table . '.t3ver_wsid=0 OR '
+							. $table . '.t3ver_wsid=' . intval($this->versioningWorkspaceId)
+							. ')';
+					}
+				}
+
+				// Filter out versioned records
+				if (!$noVersionPreview) {
+					$query .= ' AND ' . $table . '.pid<>-1';
+				}
 			}
 
 				// Enable fields:
@@ -1452,4 +1469,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_page.php']);
 }
 
-?>
\ No newline at end of file
+?>
