@@ -1824,7 +1824,7 @@ class t3lib_sqlparser {
 		$query = 'CREATE TABLE ' . $components['TABLE'] . ' (
 			' . implode(',
 			', $fieldsKeys) . '
-			)' . ($components['tableType'] ? ' TYPE=' . $components['tableType'] : '');
+			)' . ($components['tableType'] ? ' ENGINE=' . $components['tableType'] : '');
 
 		return $query;
 	}
@@ -2257,4 +2257,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_sqlparser.php']);
 }
 
-?>
\ No newline at end of file
+?>
