@@ -834,6 +834,8 @@ class t3lib_transferData {
 			// foreign_table
 		$subres = t3lib_BEfunc::exec_foreign_table_where_query($fieldConfig, $field, $TSconfig);
 		while ($subrow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($subres)) {
+			// Resolve move-placeholder, to check the right uid against $dataIds
+			t3lib_BEfunc::workspaceOL($fieldConfig['config']['foreign_table'], $subrow);
 			$recordList[$subrow['uid']] = t3lib_BEfunc::getRecordTitle($fieldConfig['config']['foreign_table'], $subrow);
 		}
 
@@ -841,6 +843,8 @@ class t3lib_transferData {
 		if (is_array($TCA[$fieldConfig['config']['neg_foreign_table']])) {
 			$subres = t3lib_BEfunc::exec_foreign_table_where_query($fieldConfig, $field, $TSconfig, 'neg_');
 			while ($subrow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($subres)) {
+				// Resolve move-placeholder, to check the right uid against $dataIds
+				t3lib_BEfunc::workspaceOL($fieldConfig['config']['nes_foreign_table'], $subrow);
 				$recordList[-$subrow['uid']] = t3lib_BEfunc::getRecordTitle($fieldConfig['config']['neg_foreign_table'], $subrow);
 			}
 		}
@@ -1014,4 +1018,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_transferdata.php']);
 }
 
-?>
\ No newline at end of file
+?>
