@@ -712,6 +712,10 @@ class t3lib_TSparser {
 					$realFileName = t3lib_div::getFileAbsFileName($fileName);
 
 						// some file checks
+					if (!t3lib_div::verifyFilenameAgainstDenyPattern($realFileName)) {
+						throw new Exception(sprintf('File "%s" was not included since it is not allowed due to fileDenyPattern.', $fileName));
+					}
+
 					if (empty($realFileName)) {
 						throw new Exception(sprintf('"%s" is not a valid file location.', $fileName));
 					}
