@@ -733,6 +733,7 @@ class t3lib_userAuth {
 			}
 
 		} elseif ($activeLogin || count($tempuserArr)) {
+			t3lib_utility_Http::setResponseCode(t3lib_utility_Http::HTTP_STATUS_401);
 			$this->loginFailure = TRUE;
 
 			if ($this->writeDevLog && !count($tempuserArr) && $activeLogin) {
@@ -1393,10 +1394,13 @@ class t3lib_userAuth {
 	/**
 	 * DUMMY: Check login failures (in some extension classes)
 	 *
-	 * @return	void
+	 * @param string $email Email address
+	 * @param integer $secondsBack Number of sections back in time to check. This is a kind of limit for how many failures an hour for instance
+	 * @param integer $maxFailures Max allowed failures before a warning mail is sent
+	 * @return void
 	 * @ignore
 	 */
-	function checkLogFailures() {
+	function checkLogFailures($email, $secondsBack, $maxFailures) {
 	}
 
 	/**
