@@ -406,14 +406,20 @@ class tslib_gifBuilder extends t3lib_stdGraphic {
 			foreach($sKeyArray as $theKey)	{
 				$theValue=$this->setup[$theKey];
 				if (intval($theKey) && $conf=$this->setup[$theKey.'.'])	{
-					$isStdWrapped = array();
-					foreach($conf as $key => $value) {
-						$parameter = rtrim($key,'.');
-						if(!$isStdWrapped[$parameter] && isset($conf[$parameter.'.'])) {
-							$conf[$parameter] = $this->cObj->stdWrap($conf[$parameter], $conf[$parameter.'.']);
-							$isStdWrapped[$parameter] = 1;
+					// apply stdWrap to all properties, except for TEXT objects
+					// all properties of the TEXT sub-object have already been stdWrap-ped
+					// before in ->checkTextObj()
+					if ($theValue !== 'TEXT') {
+						$isStdWrapped = array();
+						foreach ($conf as $key => $value) {
+							$parameter = rtrim($key, '.');
+							if (!$isStdWrapped[$parameter] && isset($conf[$parameter . '.'])) {
+								$conf[$parameter] = $this->cObj->stdWrap($conf[$parameter], $conf[$parameter . '.']);
+								$isStdWrapped[$parameter] = 1;
+							}
 						}
 					}
+
 					switch($theValue)	{
 							// Images
 						case 'IMAGE':
