@@ -47,9 +47,9 @@ if (version_compare(phpversion(), '5.2', '<'))	die ('TYPO3 requires PHP 5.2.0 or
 // Set error reporting
 // *******************************
 if (defined('E_DEPRECATED')) {
-	error_reporting(E_ALL ^ E_NOTICE ^ E_DEPRECATED);
+    error_reporting(E_ALL & ~(E_STRICT | E_NOTICE | E_DEPRECATED));
 } else {
-	error_reporting(E_ALL ^ E_NOTICE);
+    error_reporting(E_ALL ^ E_NOTICE);
 }
 
 
