@@ -699,7 +699,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 				$titleText = trim($this->cObj->stdWrap($imgConf['titleText'], $imgConf['titleText.']));
 				if ($titleText)	{
 						// This will be used by the IMAGE call later:
-					$GLOBALS['TSFE']->ATagParams .= ' title="'. $titleText .'"';
+					$GLOBALS['TSFE']->ATagParams .= ' title="'. htmlspecialchars($titleText) .'"';
 				}
 			}
 
@@ -1046,4 +1046,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/css_styled_content/pi1/class.tx_cssstyledcontent_pi1.php']);
 }
 
-?>
\ No newline at end of file
+?>
