@@ -398,12 +398,6 @@ class Tx_Extbase_MVC_Controller_ActionController extends Tx_Extbase_MVC_Controll
 		}
 
 		$message = 'An error occurred while trying to call ' . get_class($this) . '->' . $this->actionMethodName . '().' . PHP_EOL;
-		foreach ($this->argumentsMappingResults->getErrors() as $error) {
-			$message .= 'Error:   ' . $error->getMessage() . PHP_EOL;
-		}
-		foreach ($this->argumentsMappingResults->getWarnings() as $warning) {
-			$message .= 'Warning: ' . $warning->getMessage() . PHP_EOL;
-		}
 		return $message;
 	}
 
