@@ -299,7 +299,7 @@ class Tx_Extbase_Tests_Unit_Persistence_RepositoryTest extends Tx_Extbase_Tests_
 		$existingObject = $this->getMock('Tx_Extbase_DomainObject_DomainObjectInterface');
 		$newObject = $this->getMock('Tx_Extbase_DomainObject_DomainObjectInterface');
 
-		$removedObjects = new SplObjectStorage;
+		$removedObjects = new Tx_Extbase_Persistence_ObjectStorage();
 		$removedObjects->attach($existingObject);
 
 		$mockBackend = $this->getMock('Tx_Extbase_Persistence_BackendInterface');
@@ -330,7 +330,7 @@ class Tx_Extbase_Tests_Unit_Persistence_RepositoryTest extends Tx_Extbase_Tests_
 		$existingObject = $this->getMock('Tx_Extbase_DomainObject_DomainObjectInterface');
 		$newObject = $this->getMock('Tx_Extbase_DomainObject_DomainObjectInterface');
 
-		$addedObjects = new SplObjectStorage;
+		$addedObjects = new Tx_Extbase_Persistence_ObjectStorage();
 		$addedObjects->attach($existingObject);
 
 		$mockBackend = $this->getMock('Tx_Extbase_Persistence_BackendInterface');
@@ -423,6 +423,34 @@ class Tx_Extbase_Tests_Unit_Persistence_RepositoryTest extends Tx_Extbase_Tests_
 		$this->assertSame($object, $this->repository->findOneByFoo('bar'));
 	}
 
+	/**
+	 * @test
+	 */
+	public function magicCallMethodReturnsFirstArrayKeyInFindOneBySomethingIfQueryReturnsRawResult() {
+		$queryResultArray = array(
+			0 => array(
+				'foo' => 'bar',
+			),
+		);
+		$this->mockQuery->expects($this->once())->method('equals')->with('foo', 'bar')->will($this->returnValue('matchCriteria'));
+		$this->mockQuery->expects($this->once())->method('matching')->with('matchCriteria')->will($this->returnValue($this->mockQuery));
+		$this->mockQuery->expects($this->once())->method('setLimit')->with(1)->will($this->returnValue($this->mockQuery));
+		$this->mockQuery->expects($this->once())->method('execute')->will($this->returnValue($queryResultArray));
+		$this->assertSame(array('foo' => 'bar'), $this->repository->findOneByFoo('bar'));
+	}
+
+	/**
+	 * @test
+	 */
+	public function magicCallMethodReturnsNullInFindOneBySomethingIfQueryReturnsEmptyRawResult() {
+		$queryResultArray = array();
+		$this->mockQuery->expects($this->once())->method('equals')->with('foo', 'bar')->will($this->returnValue('matchCriteria'));
+		$this->mockQuery->expects($this->once())->method('matching')->with('matchCriteria')->will($this->returnValue($this->mockQuery));
+		$this->mockQuery->expects($this->once())->method('setLimit')->with(1)->will($this->returnValue($this->mockQuery));
+		$this->mockQuery->expects($this->once())->method('execute')->will($this->returnValue($queryResultArray));
+		$this->assertNull($this->repository->findOneByFoo('bar'));
+	}
+
 	/**
 	 * @test
 	 */
@@ -438,7 +466,7 @@ class Tx_Extbase_Tests_Unit_Persistence_RepositoryTest extends Tx_Extbase_Tests_
 
 	/**
 	 * @test
-	 * @expectedException Exception
+	 * @expectedException Tx_Extbase_Persistence_Exception_UnsupportedMethod
 	 */
 	public function magicCallMethodTriggersAnErrorIfUnknownMethodsAreCalled() {
 		$this->repository->__call('foo', array());
@@ -465,4 +493,4 @@ class Tx_Extbase_Tests_Unit_Persistence_RepositoryTest extends Tx_Extbase_Tests_
 	}
 
 }
-?>
\ No newline at end of file
+?>
