@@ -299,7 +299,12 @@ class SC_mod_tools_config_index {
 					$flashMessage = t3lib_div::makeInstance(
 						't3lib_FlashMessage',
 						'',
-						sprintf($GLOBALS['LANG']->getLL('writeMessage', TRUE), TYPO3_extTableDef_script,  '<br />', '<strong>' . nl2br($changedLine) . '</strong>'),
+						sprintf(
+							$GLOBALS['LANG']->getLL('writeMessage', TRUE),
+							TYPO3_extTableDef_script,
+							'<br />',
+							'<strong>' . nl2br(htmlspecialchars($changedLine)) . '</strong>'
+						),
 						t3lib_FlashMessage::OK
 					);
 				} else {
