@@ -128,7 +128,7 @@ class SC_db_list {
 		$this->perms_clause = $BE_USER->getPagePermsClause(1);
 
 			// GPvars:
-		$this->id = t3lib_div::_GP('id');
+		$this->id = (int) t3lib_div::_GP('id');
 		$this->pointer = t3lib_div::_GP('pointer');
 		$this->imagemode = t3lib_div::_GP('imagemode');
 		$this->table = t3lib_div::_GP('table');
@@ -225,6 +225,7 @@ class SC_db_list {
 		}
 
 			// Initialize the dblist object:
+		/** @var $dblist localRecordList */
 		$dblist = t3lib_div::makeInstance('localRecordList');
 		$dblist->backPath = $BACK_PATH;
 		$dblist->script = t3lib_BEfunc::getModuleUrl('web_list', array(), '');
